<template>
  <div id="chartOfContributionRate" class="chartOfContributionRate" />
</template>

<script>
import * as echarts from 'echarts'
export default {
  props: {
    contributionRateData: {
      type: Object,
      default: () => {}
    }
  },
  data() {
    return {
      kindArray: []
    }
  },
  computed: {
  },
  created() {
  },
  mounted() {
    this.initCharts()
  },
  watch: {
    contributionRateData(newV, oldV) {
      this.initCharts()
    }
  },
  methods: {
    // 处理series数据
    // 加载echarts
    initCharts() {
      const time = this.contributionRateData.time
      delete this.contributionRateData.time
      const hangyes = Object.keys(this.contributionRateData)
      const index = hangyes.indexOf('本市')
      const benshi = hangyes.splice(index, 1)[0]
      hangyes.push(benshi)
      const app = {}

      const chartDom = document.getElementById('chartOfContributionRate')
      const myChart = echarts.init(chartDom)
      const series = []
      app.config = {
        rotate: 0,
        align: 'center',
        verticalAlign: 'middle',
        position: 'top',
        distance: 15,
        onChange: function() {
          const labelOption = {
            rotate: app.config.rotate,
            align: app.config.align,
            verticalAlign: app.config.verticalAlign,
            position: app.config.position,
            distance: app.config.distance
          }
          myChart.setOption({
            series: [
              {
                label: labelOption
              },
              {
                label: labelOption
              },
              {
                label: labelOption
              },
              {
                label: labelOption
              }
            ]
          })
        }
      }
      const labelOption = {
        show: true,
        rotate: app.config.rotate,
        align: app.config.align,
        verticalAlign: app.config.verticalAlign,
        position: app.config.position,
        distance: app.config.distance,
        color: 'gray',
        formatter: function(param) {
          if (param.data.name) {
            return param.data.value + '(' + param.data.name + ')'
          } else {
            return param.data.value
          }
        },
        fontSize: 12,
        rich: {
          name: {}
        }}
      hangyes.forEach(item => {
        if (item in this.contributionRateData) {
          const obj = {
            name: item,
            type: 'bar',
            barGap: 0,
            label: labelOption,
            emphasis: {
              focus: 'series'
            },
            data: this.contributionRateData[item].data
          }
          series.push(obj)
        }
      })
      const option = {
        tooltip: {
          trigger: 'axis',
          formatter: function(params) {
            let html = params[0].axisValue + '</br>'
            for (let i = 0; i < params.length; i++) {
              html = html +
                  `<span style="background-color: ${params[i].color}; width: 14px; height: 12px;display: inline-block;margin-right: 4px;border-radius: 4px"></span>` +
                  params[i].seriesName + ': ' + (params[i].value === null ? '-' : params[i].value) + '</br>'
            }
            return html
          },
          backgroundColor: 'rgba(255,255,255,1)', // 通过设置rgba调节背景颜色与透明度
          color: 'gray',
          borderWidth: '1',
          borderColor: '#d9d9d9',
          textStyle: {
            color: '#808080'
          },
          axisPointer: {
            type: 'shadow',
            lineStyle: {
              color: 'rgba(128, 128, 128, .6)'
            }
          }

        },
        legend: {
          data: hangyes
        },
        toolbox: {
          show: true,
          orient: 'vertical',
          left: 'right',
          top: 'top',
          feature: {
            saveAsImage: { show: true }
          }
        },
        xAxis: [
          {
            type: 'category',
            axisTick: { show: false },
            data: time
          }
        ],
        yAxis: [
          {
            type: 'value'
          }
        ],
        dataZoom: [
          {
            type: 'inside'
          }
        ],
        series: series
      }

      option && myChart.setOption(option)
    }
  }
}
</script>

<style lang="less">
.chartOfContributionRate {
  width: 100%;
  height: 460px;
  div:nth-child(1) {
    width: 100%!important;
    top: 40px!important;
    left: -10px;
    canvas {
      width: 100%!important;
    }
  }
}
</style>
